@@ -13,16 +13,21 @@
 #' @export
 #' @importFrom scales alpha
 #' @importFrom grid polygonGrob gpar
+#' @importFrom ggplot2 zeroGrob
 draw_key_star <- function(data, params, size){
     if (is.null(data$starshape)) {
         data$starshape <- 1
     } else if (! is.numeric(data$starshape)) {
         data$starshape <- translate_starshape(data$starshape)
     }
-    starGrob(x=0.5, y=0.5,
-             starshape=data$starshape,
-             gp=gpar(fill=alpha(data$fill, data$alpha),
-                     col =alpha(data$colour, data$alpha),
-                     fontsize = ((data$size %||% 1.5) * .pt + (data$starstroke %||% 0.5) * .starstroke / 2)/5,
-                     lwd = (data$starstroke %||% 0.5) * .starstroke / 2))
+    if (is.na(data$starshape)){
+        zeroGrob()
+    }else{
+        starGrob(x=0.5, y=0.5,
+                 starshape=data$starshape,
+                 gp=gpar(fill=alpha(data$fill, data$alpha),
+                         col =alpha(data$colour, data$alpha),
+                         fontsize = ((data$size %||% 1.5) * .pt + (data$starstroke %||% 0.5) * .starstroke / 2)/5,
+                         lwd = (data$starstroke %||% 0.5) * .starstroke / 2))
+    }
 }
